#version 150 compatibility

#include "../sampleFetch.glsl"
uniform sampler2D worldNormalIDMap;
uniform sampler2D mvPosMap;
uniform sampler2D diffuseEnvMap;
uniform sampler2D specularEnvMap;


uniform sampler2D diffuseComponent;
uniform sampler2D specularComponent;




uniform mat4 In_ProjectionMatrix;

uniform float specularIntensity;
uniform float radius;
uniform float shininess;
uniform float fresnelMin;
uniform float finalIntensity;
uniform float diffuseIntensity;

uniform vec3 viewDirection;


out vec4 FragColor[1];

vec2 getUV(vec3 carthesian)
{
	float x = (atan(carthesian.x, carthesian.z) + 3.14159265) /2.0/3.14159265;
	float y = 1-acos(carthesian.y)/3.14159265;//(carthesian.y + 1) * 0.5;//
	return vec2(x , y )  ;
}

void main (void) {


    vec4 n = texture (worldNormalIDMap, gl_TexCoord[0].st);
    if (n.w < 0.5){
		FragColor[0] = vec4(1);
		return;	
	}

	vec3 diffuseDirection = n.xyz;
	vec3 specularDirection = reflect(viewDirection,  n.xyz);
	
	vec2 diffuseTexCoord = getUV(diffuseDirection) ;
	vec2 specularTexCoord = getUV(specularDirection) ;
	
	float fresnelTerm = pow(1 - dot(-n.xyz, viewDirection), shininess) + fresnelMin; 
	vec4 diffuseColor = texture (diffuseEnvMap,  diffuseTexCoord )/10.0 * diffuseIntensity;
	vec4 specularColor = texture (specularEnvMap, specularTexCoord ) /100.0 * specularIntensity * fresnelTerm ;
	
	
	vec4 dif = texture (diffuseComponent, gl_TexCoord[0].st);
	vec4 sep = texture (specularComponent, gl_TexCoord[0].st);

	vec4 color = (diffuseColor * dif + specularColor * sep);
	
    FragColor[0] = color * finalIntensity;
}
